@@ -1,7 +1,12 @@
 import threading
-import time
+
+# import time
+from .common.tools import *
+
+# 保持兼容
 TIME_ACCURACY = 1  # 时间精度，时间精度不是越小越好！你的Task每次循环超过了这个值,将影响准确度
 
+
 def IntervalTask(sec, func, params=(), immediatly=True, thread_name=''):
     def run(*func_params):
         if immediatly is False:
@@ -29,4 +34,4 @@ def normal_task(sec, func, params=(), thread_name=''):
     t.start()
     # t.join()
     # threading.enumerate()
-    # dbg(threading.enumerate())
\ No newline at end of file
+    # dbg(threading.enumerate())
